# pykumaapi

Библиотека для работы с Kaspersky Unified Monitoring and Analysis Platform
по API

Необходимо установить библиотеку:
 pip install pykumaapi

В проекте сделать импорт

from pykumaapi.pykumaapi import getevent

Созданы функции:
1) getevent()

Необходимо передать функции следующие параметры:

    url: 
    api_key_user:
    clusterID:
    sql:
    period_from:
    period_to: :